===============
Outreach
===============

The project zfit aims to establish a basis in terms of API and basic functionality for a (likelihood) fitting
ecosystem that is capable to deal with the demands from High Energy Physics (HEP).

Papers and proceedings
=======================

- `Original zfit paper <https://www.sciencedirect.com/science/article/pii/S2352711019303851>`_
- `Computing in High Energy Physics (CHEP) 2019 <https://www.epj-conferences.org/articles/epjconf/ref/2020/21/epjconf_chep2020_06025/epjconf_chep2020_06025.html>`_
- `PyHEP 2020 tutorial <https://zenodo.org/record/4147540#.YHSdF3UzZH4>`_
- `PyHEP 2020 presentation <https://zenodo.org/record/4147528#.YHSdkHUzZH4>`_
- `PyHEP 2019 presentation <https://zenodo.org/record/3960059#.YHSdUnUzZH4>`_



Material
=========

:download:`zfit logo high resolution <../images/zfit-logo_veryhires.png>`

:download:`zfit logo normal resolution <../images/zfit-logo_hires.png>`

:download:`zfit vectorgraphics <../images/zfit-vector.svg>`

:download:`zfit favicon <../images/zfit-favicon.png>`

:download:`zfit workflow <../images/zfit_workflow_v2.png>`

If there is material missing, do not hesitate to contact us.
